@@ -76,6 +76,13 @@ function requiresFramework(minVersion, maxVersion) {
     }
 }
 
+function checkMinVersion(minVersion) {
+    var frameworkV = getVersionNumber(RSettings.getMajorVersion(), RSettings.getMinorVersion(), RSettings.getRevisionVersion(), RSettings.getBuildVersion());
+    var minV = getVersionNumber(minVersion[0], minVersion[1], minVersion[2], minVersion[3]);
+
+    return frameworkV >= minV;
+}
+
 function getVersionNumber(major, minor, revision, build) {
     return major*1e9 + minor*1e6 + revision*1e3 + build;
 }
@@ -158,7 +165,7 @@ function destrDialog(dlg) {
  * Get pointer from shared pointer object using data() (Qt5) or implicitly (Qt6).
  */
 function getPtr(p) {
-    if (RSettings.getQtVersion() > 0x060000) {
+    if (RSettings.getQtVersion() >= 0x060000) {
         return p;
     }
     else {
@@ -182,8 +189,17 @@ function isNull(obj) {
         return true;
     }
 
+    if (obj==null) {
+        return true;
+    }
+
+    if (RSettings.getQtVersion() >= 0x060000) {
+        if (obj.hasOwnProperty("__PROXY__")) {
+            return isNull(obj.__PROXY__);
+        }
+    }
+
     return (
-        obj==null ||
         // wrapped object is NULL:
         (typeof(obj.isNullWrapper)==="function" && obj.isNullWrapper()===true) ||
         // shared pointer is NULL:
@@ -2566,43 +2582,33 @@ function shapeToEntity(document, shape) {
         return undefined;
     }
 
-    var s = shape;
-    if (isFunction(s.data)) {
-        s = s.data();
-    }
+    var s = getPtr(shape);
 
-    if (isPointShape(s)) {
+    switch (s.getShapeType()) {
+    case RShape.Point:
         return new RPointEntity(document, new RPointData(s.getPosition()));
-    }
-    else if (isLineShape(s)) {
+    case RShape.Line:
         return new RLineEntity(document, new RLineData(s));
-    }
-    else if (isRayShape(s)) {
+    case RShape.Ray:
         return new RRayEntity(document, new RRayData(s));
-    }
-    else if (isXLineShape(s)) {
+    case RShape.XLine:
         return new RXLineEntity(document, new RXLineData(s));
-    }
-    else if (isArcShape(s)) {
+    case RShape.Arc:
         return new RArcEntity(document, new RArcData(s));
-    }
-    else if (isCircleShape(s)) {
+    case RShape.Circle:
         return new RCircleEntity(document, new RCircleData(s));
-    }
-    else if (isEllipseShape(s)) {
+    case RShape.Ellipse:
         return new REllipseEntity(document, new REllipseData(s));
-    }
-    else if (isPolylineShape(s)) {
+    case RShape.Polyline:
         return new RPolylineEntity(document, new RPolylineData(s));
-    }
-    else if (isSplineShape(s)) {
+    case RShape.Spline:
         return new RSplineEntity(document, new RSplineData(s));
-    }
-    else if (isTriangleShape(s)) {
+    case RShape.Triangle:
         return new RSolidEntity(document, new RSolidData(s));
+    default:
+        return undefined;
     }
 
-    qWarning("shapeToEntity: unknown shape: ", s);
     return undefined;
 }
 
@@ -2657,21 +2663,15 @@ function modifyEntity(op, entity, shape) {
         (isCircleEntity(entity) && isArcShape(shape))) {
 
         var e = shapeToEntity(entity.getDocument(), shape);
-//        if (isFunction(entity.data)) {
-//            e.copyAttributesFrom(entity.data());
-//            op.deleteObject(entity.data());
-//        }
-//        else {
-            e.copyAttributesFrom(entity);
-            op.deleteObject(entity);
-//        }
+        e.copyAttributesFrom(getPtr(entity));
+        op.deleteObject(entity);
 
         op.addObject(e, false);
         return true;
     }
 
     if (isFunction(entity.setShape)) {
-        entity.setShape(shape);
+        entity.setShape(getPtr(shape));
         op.addObject(entity, false);
         return true;
     }
